# -*- coding: utf-8 -*-
import sys
import requests
import json
from xml.etree import ElementTree as ET


class LipyNotify(object):

    def __init__(self):
        self.url = "https://notify-api.line.me/api/notify"
        self.headers = {
            "Content-Type": "application/x-www-form-urlencoded"
        }
        self.token = None

    def set_token(self, token):
        self.token = token
        self.headers["Authorization"] = "Bearer " + token

    def send_txt(self, message):
        if self.token is None:
            sys.stderr.write(
                "Message can't be sent. You must set your authorization token with set_token method")
        else:
            payload = {"message": message}
            resp = requests.post(self.url, data=payload, headers=self.headers)

    def send_image(self, message, image_url):
        if self.token is None:
            sys.stderr.write(
                "Message can't be sent. You must set your authorization token with set_token method")
        else:
            payload = {
                "message": message,
                "imageThumbnail": image_url,
                "imageFullsize": image_url}
            resp = requests.post(self.url, data=payload, headers=self.headers)
            self._validate_response(resp)

    def send_cat_image(self):
        api_url = "http://thecatapi.com/api/images/get"
        params = {
            "type": "jpg",
            "size": "med",
            "format": "xml"
        }
        r = requests.get(api_url, params=params)
        tree = ET.fromstring(r.text)
        image_url = tree.findall(".//url")[0].text

        self.send_image(message="にゃーん", image_url=image_url)

    def _validate_response(self, resp):
        resp = resp.json()
        if resp["status"] == 200:
            sys.stderr.write("Message sent successfully")
        else:
            sys.stderr.write("Message was not sent properly")



#!/usr/bin/env python
# -*- coding:utf-8 -*-
from __future__ import absolute_import
from __future__ import unicode_literals
import os
from setuptools import setup, find_packages

readme = 'Send message to Line.app'
if os.path.exists('README.txt'):
    readme = open('README.txt').read()


def _requires_from_file(filename):
    return open(filename).read().splitlines()

# version
here = os.path.dirname(os.path.abspath(__file__))
version = next((line.split('=')[1].strip().replace("'", '')
                for line in open(os.path.join(here,
                                              'lipy_notify',
                                              '__init__.py'))
                if line.startswith('__version__ = ')),
               '0.0.1')

setup(
    name="lipy_notify",
    version=version,
    url='https://github.com/butsugiri',
    author='shunk52',
    author_email='shunk52@gmail.com',
    description='Post message to LINE.app from python',
    long_description=readme,
    packages=find_packages(),
    license="MIT",
    classifiers=[
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'License :: OSI Approved :: MIT License',
    ],
    install_requires=[
        "requests"
    ],
)
